
import { H4 } from "../components/Headings";
import { LoremMedium } from "../components/Loremipsum";
import { SupScrollLink } from "../components/ScrollLink";
import { Section, Subesction } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";


export const Safety: React.FC = () =>{
  useTabNavigation();
  
  return (
    <>
      <Section title="Role in iGem" id="Role">
        <LoremMedium/>
      </Section>
      <Section title="Check-Ins" id="Check-Ins">
        <LoremMedium/>
      </Section>
      <Section title="Our Lab" id="Our Lab">
        <LoremMedium/>
      </Section>
      <Section title="Biosafety" id="Biosafety">
        <Subesction title="Mechanism" id="Biosafety1">
          <LoremMedium/>
        </Subesction>
        <Subesction title="Delivery" id="Biosafety2">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="Biosecurity" id="Biosecurity">
        <Subesction title="Our Project" id="Biosecurity1">
          <LoremMedium/>
        </Subesction>
        <Subesction title="Risk Assesment" id="Biosecurity2">
          <LoremMedium/>
        </Subesction>
        <Subesction title="Managing Risks" id="Biosecurity3">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="Bioethics" id="Bioethics">
            <div>
                <p>
                    Bioethics is an interdisciplinary field of research that addresses ethical issues pertaining to the life sciences and medical research. It plays a pivotal role in contemporary research, particularly in projects that employ human samples or data. This is due to the fact that in these cases, the protection of the rights and dignity of the people involved is of the utmost importance <SupScrollLink label="1"/> (Chadwick_2012_Thiele_2001a). In order to ascertain the necessity for an ethics application, an interview was conducted with Eva-Maria Berens, the scientific director of the office of the Ethics Committee at Bielefeld University, as part of the current research project. Following a comprehensive review, it was concluded that an ethics application was not necessary for the specific research project. Nevertheless, a comprehensive patient consent form was developed in conjunction with Eva-Maria Berens to guarantee that the donors of their samples are adequately informed and provide their consent of their own volition. The document guarantees that all pertinent information regarding sample collection, utilisation and storage is provided in an intelligible format. Furthermore, an interview was conducted with Dr. Timm Weber, a representative of the biobank, to discuss the topic of bioethics in greater depth. During the course of the interviews, the ethical aspects of sample storage and utilisation within the biobank were discussed in detail. Particular attention was paid to the responsible handling and protection of the rights of the test subjects. The discussion of bioethics in both interviews emphasises the relevance of ethical principles for research and ensures that it is conducted in accordance with the highest ethical standards.
                </p>
            </div>
        <Subesction title="Gene Therapy" id="Bioethics1">
          <div>
                <p>
                The potential of gene therapy to treat genetic diseases is promising, but it is also associated with significant ethical issues. One of the principal challenges is ensuring the safety of the procedure and the potential for unforeseen long-term consequences. Such consequences may only become apparent years after the genetic intervention has taken place. The modification of the germline, which affects not only the individual but also future generations, is a particularly sensitive issue. This gives rise to the question of the extent to which the decisions made today will influence future generations without their consent, thereby jeopardising intergenerational justice <SupScrollLink label="2"/> (Rubeis_Steger_2018). Another ethical issue is the potential for misuse for eugenic purposes. While the current focus is on combating disease, future applications could be aimed at 'optimising' human traits, which could result in a worsening of social inequalities. Access to gene therapy is also a significant issue. High costs could limit access to wealthy population groups, which would reinforce existing inequalities <SupScrollLink label="3"/> (Ansah_2022_Cornetta_Patel_Wanjiku_Busakhala_2018). The issue of informed consent is also a key aspect. Many patients do not have the necessary knowledge to fully understand the complex risks, which raises ethical questions about their decision-making capacity. Overall, the debate around gene therapy highlights that ethical considerations such as safety, justice and patient rights need to be considered alongside scientific progress <SupScrollLink label="4"/> (Pugh_2020).  
                </p>
          </div>
        </Subesction>
        <Subesction title="Primary Cells" id="Bioethics2">
          <div>
            <H4 text="Introduction of primary cultures"></H4>
            <p>
            A primary culture is defined as a cell culture that is isolated directly from the tissue of an organism. In our case, the organism is human. The cells are then cultivated in a controlled environment, namely an S2 laboratory <SupScrollLink label="5"/> (Gstraunthaler_Lindl_2013). Primary cultures are a fundamental biomedical research tool, widely regarded as indispensable due to their capacity for realistic modelling of complex cell interactions. Primary cells are derived directly from the tissue of an organism and, as a consequence, they essentially retain their original properties. Consequently, they mirror the authentic conditions of the target tissue, which is vital for accurately assessing the impact of a therapeutic agent. In contrast, HEK cells represent transformed cell lines that exhibit physiological properties distinct from those of target cells in the human body. The effect of a therapeutic agent is typically limited to a specific cell type. The investigation of cell-specific effects and reactions of an active substance is feasible with the use of primary cells, as these possess the functional characteristics inherent to the cell type under consideration. Although HEK cells are relatively straightforward to cultivate, they are less representative of a number of tissue types and may activate other signalling pathways. The authenticity of the receptors and signalling pathways is guaranteed, as primary cells show the natural expression of receptors, ion channels and other cellular mechanisms. HEK cells are often genetically modified to express specific receptors, which can be useful for simple test systems. However, this does not reflect the complex environment of a real tissue. Given the sensitivity of primary cultures to environmental influences, thus resulting in higher risk of a contamination, it is imperative that researchers employ special safety measures to ensure the safety of themselves and the integrity of the cells. Primary cultures are employed extensively in the development of vaccines, cancer research and the investigation of basic cell processes. 
            </p>
            <H4 text="Ethics in work with primary cultures"></H4>
            <p>
                The term 'ethics' is used to describe the examination of moral principles that determine the behaviour of individuals or groups <SupScrollLink label="6"/> (Thiele_2001b). In a scientific context, the term 'ethics' encompasses the examination of the moral justifiability of actions and decisions, particularly with regard to the welfare of living beings and the responsible use of resources <SupScrollLink label="7"/> (Gethmann_2001). The isolation of primary cells from living organisms raises ethical questions, particularly in the case of human or animal tissue. In the context of research with animal primary cells, careful consideration must be given to the need for animal suffering and the potential benefits of the research <SupScrollLink label="8"/> (Kiani_Pheby_Henehan_Brown_Sieving_Sykora_Marks_Falsini_Capodicasa_Miertus_et al._2022). An ethical dilemma frequently arises from the fact that primary cells offer the most meaningful data from a biological standpoint, yet their production is associated with challenges. In this context, the necessity of primary cell cultures is called into question, and the promotion of alternative methods, such as artificially produced tissues or organoids, is advocated where feasible. It is of crucial importance to emphasize the necessity of ethical responsibility in the collection of primary cultures. It is of the utmost importance that the procedure is carried out with consideration for the rights, and particularly the well-being of the donor. The removal of cells or tissue must be medically justifiable and, moreover, ethically justifiable in every case. To this end, the potential for research use and the possible risks and burdens for the donor must be weighed against each other to ensure careful consideration. However, it is also particularly important to ensure that the donor is involved in the entire process and is able to make an informed decision. The purpose of the research, the use of the cells and possible consequences must also be made transparent at all times. 
                The obtaining of informed consent represents a fundamental aspect of ethical practice in the collection of primary cells. This process must encompass not only a formal consent procedure, but also the provision of comprehensive information to donors regarding the collection, utilisation and prospective future applications of the cells. The act of consent must be given freely and without undue influence, and donors must be fully aware of the consequences of their participation. Furthermore, donors must be granted the right to revoke their consent at any time without consequence. Prior to the collection of cells, a comprehensive discussion is held with the donor, during which all pertinent details are elucidated and any queries or concerns they may have, are addressed. This guarantees that the donor is adequately informed and is thus able to make an autonomous decision based on a comprehensive understanding of the procedure. 
                The protection of privacy and confidentiality is of paramount importance when working with primary cultures. Given that primary cultures are predominantly human tissue, they contain genetic information and other personal data that is sensitive and deserving of protection. It is therefore of great importance that the data is anonymized and kept strictly confidential in order to protect the identity of the donor. 
                Every person who has access to the data or samples must be obliged to comply with confidentiality standards. It must be ensured that all legal requirements for data protection are met, including compliance with data protection laws such as the GDPR in the EU. 
            </p>
            <H4 text="Safety aspects when working with primary cultures "></H4>
            <p>
            When working with primary cultures, there is a risk that the cells may be potentially infectious samples or contaminated. Therefore, it is of the utmost importance to adhere to strict biological safety measures in order to minimize the risk of exposure to dangerous pathogens. This includes the use of personal protective equipment, working in a biosafety cabinet and adhering to decontamination protocols.
            The overarching objective is the safeguarding of laboratory staff. This is achieved through the utilization of personal protective equipment, encompassing gloves, lab coats and safety goggles, in addition to the provision of training in pertinent safety protocols. 
            In order to prevent the release of potentially hazardous material, it is imperative that biological waste is disposed of in accordance with the established regulatory framework. The waste is subjected to rigorous sterilisation by autoclaving and subsequently rendered safe for disposal in the designated and labelled containers. 
            </p>
            <H4 text="Regulatory framework"></H4>
            <p>
            The field of primary culture research is subject to a plethora of legal regulations and guidelines at both the national and international levels. These regulations dictate the manner in which primary cultures may be obtained, used, and disposed of. They encompass regulations pertaining to the protection of donors, the secure handling of biological material, and the ethical responsibility towards the cells and their origin. It is of paramount importance that all laboratory practices align with these regulations. 
            </p>
          </div>
        </Subesction>
        <Subesction title="Consent and Guidelines" id="Bioethics3">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="References" id="References">
                <ol>
                    {/* <!-- Citation num 1--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 2--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 3--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 4--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 5--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 6--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 7--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                    {/* <!-- Citation num 8--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                {/* <!-- Citation num 9--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                    {/* <!-- Citation num 10--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                </ol>
            </Section>
    </>
  );
}
